<div class="table-container">
    <table class="table table-hover table-headings">
        <thead>
            <tr>
                <th class="orderable">                            
                    <a href="?sort=assigned_object">CI</a>                
                </th>        
                <th class="orderable">                
                        <a href="?sort=obj_type">Type</a>                
                </th>
                <th>

                </th>
            </tr>
            <tbody>
                {% for ci in config_items %}
                <tr class={% if forloop.counter|divisibleby:2 %} "even" {% else %} "odd" {% endif %}>
                    <td>
                        <a href="{{ ci.get_absolute_url }}">{{ ci }}</a>
                    </td>
                    <td>
                        {{ ci.obj_type }}
                    </td>
                    <td class="text-right noprint">
                        <a href="{% url 'plugins:nb_service:IC_delete' pk=ci.pk %}?return_url={% url 'plugins:nb_service:service_IC' pk=object.pk %}" class="btn btn-danger btn-xs">
                            <i class="mdi mdi-trash-can-outline" title="Delete CI"></i>
                        </a>
                    </td>
                </tr>
                {% endfor %}
            </tbody>
        </thead>
    </table>
</div>
    

    