{% extends 'base.html' %}
{% load render_table from django_tables2 %}
{% load nb_buttons %}
{% load static %}
{% load helpers %}
{% load custom_links %}
{% load plugins %}
{% load nb_helpers %}


{% block title %}{{ object }}{% endblock %}

{% block header %}
    <div class="row noprint">        
    </div>
    <div class="pull-right noprint">
        {% edit_button object %}
        {% delete_button object %}
    </div>
    <h1>{{ object }}</h1>
    <ul class="nav nav-tabs">
        <li role="presentation">
            <a href="{{ object.get_absolute_url }}">Application</a>
        </li>
        <li role="presentation" {% if active_tab == 'device' %} class="active" {% endif %}>
            <a href="{% url 'plugins:nb_service:application_devices' pk=object.pk %}">Devices</a>
        </li>
        <li role="presentation" {% if active_tab == 'virtual_machine' %} class="active" {% endif %} >
            <a href="{% url 'plugins:nb_service:application_vms' pk=object.pk %}">Virtual Machines</a>
        </li>
    </ul>
{% endblock %}

{% block content %}
    <div class="row">
        <div class="col-md-9">
            {% render_table table %}
        </div>
    </div>     

 {% endblock %}
