from extras.plugins import PluginMenuItem


menu_items = (
    PluginMenuItem(
        link="plugins:nb_service:service_list",
        link_text="Services",
    ),
    PluginMenuItem(
        link="plugins:nb_service:application_list",
        link_text="Applications",
    ),
)
