<div class="table-container">
    <table class="table table-hover table-headings">
        <thead>
            <tr>
                <th class="orderable">                            
                    <a href="?sort=assigned_object">Source</a>                
                </th> 
                <th class="orderable">                            
                    <a href="?sort=assigned_object">Source Shape</a>                
                </th> 
                <th class="orderable">                            
                    <a href="?sort=assigned_object">Destination</a>                
                </th>
                <th class="orderable">                            
                    <a href="?sort=assigned_object">Destination Shape</a>                
                </th>     
                <th class="orderable">                            
                    <a href="?sort=assigned_object">Connector</a>                
                </th>  
                <th class="orderable">                            
                    <a href="?sort=assigned_object">Link Text</a>                
                </th>   

                <th>

                </th>
            </tr>
            <tbody>
                {% for relation in relations_objs %}
                <tr class={% if forloop.counter|divisibleby:2 %} "even" {% else %} "odd" {% endif %}>
                    <td>
                        <a href="{{ relation.source.get_absolute_url }}">{{ relation.source }}</a>
                    </td>
                    <td>
                        {{ relation.source_shape_name }}
                    </td>
                    <td>
                        <a href="{{ relation.destination.get_absolute_url }}">{{ relation.destination }}</a>
                    </td>
                    <td>
                        {{ relation.destiny_shape_name }}
                    </td>
                    <td>
                        {{ relation.connector }}
                    </td>
                    <td>
                        {{ relation.link_text }}
                    </td>
                    <td class="text-right noprint">
                        <a href="{% url 'plugins:nb_service:relation_edit' pk=relation.pk %}?return_url={% url 'plugins:nb_service:service_relation' pk=object.pk %}" class="btn btn-info btn-xs" title="Edit Relation">
                            <i class="mdi mdi-pencil"></i>
                        </a>
                        <a href="{% url 'plugins:nb_service:relation_delete' pk=relation.pk %}?return_url={% url 'plugins:nb_service:service_relation' pk=object.pk %}" class="btn btn-danger btn-xs">
                            <i class="mdi mdi-trash-can-outline" title="Delete Relation"></i>
                        </a>
                    </td>
                </tr>
                {% endfor %}
            </tbody>
        </thead>
    </table>
</div>
    

    